# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/03_sund.ipynb.

# %% auto 0
__all__ = []

# %% ../nbs/03_sund.ipynb 5
_MEMBER_NAMES_ = '_member_names_'

# %% ../nbs/03_sund.ipynb 6
_REPR_HTML_ = '_repr_html_'
_REPR_LATEX_ = '_repr_latex_'
_REPR_DATA_RESOURCE_ = '_repr_data_resource_'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/06_errs.ipynb.

# %% auto 0
__all__ = ['RET', 'ERR', 'ERRS', 'NONE', 'ERRORS', 'RETNONE', 'RETERRS', 'RETERRORS']

# %% ../nbs/06_errs.ipynb 5
RET = 'ret'
ERR = 'err'
ERRS = f'{ERR}s'
NONE = 'none'
ERRORS = f'{ERR}ors'
RETNONE = f'{RET}none'
RETERRS = f'{RET}{ERRS}'
RETERRORS = f'{RET}{ERRORS}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/57_pkgs.ipynb.

# %% auto 0
__all__ = ['NAME', 'NOTE', 'LEVEL', 'ARM', 'NO_ARM_SUPPORT', 'CFG', 'CONFIG', 'CONFIGS', 'ALWAYS', 'CHECKED', 'ENV', 'LIT', 'PIP',
           'PYPI', 'CONDA', 'PYTHON', 'DEP', 'DEPS', 'DEPENDENCIES', 'SUBCATS', 'SUBCATEGORIES', 'CHANNEL', 'CHANNELS',
           'ONLY', 'PIP_ONLY', 'CUDA_ONLY', 'PYPI_NAME']

# %% ../nbs/57_pkgs.ipynb 4
from .args import TYPE
from .exps import SUB, CATS, CATEGORIES

# %% ../nbs/57_pkgs.ipynb 5
NAME = 'name'
NOTE = 'note'

LEVEL = 'level'

ARM = 'arm'
NO_ARM_SUPPORT = f'no_{ARM}_support'

# %% ../nbs/57_pkgs.ipynb 6
CFG = 'cfg'
CONFIG = 'config'
CONFIGS = f'{CONFIG}s'

# %% ../nbs/57_pkgs.ipynb 7
ALWAYS = 'always'
CHECKED = 'checked'

# %% ../nbs/57_pkgs.ipynb 8
ENV = 'env'
LIT = 'lit'

# %% ../nbs/57_pkgs.ipynb 9
PIP = 'pip'
PYPI = 'pypi'
CONDA = 'conda'
PYTHON = 'python'

# %% ../nbs/57_pkgs.ipynb 10
DEP = 'dep'
DEPS = f'{DEP}s'
DEPENDENCIES = f'{DEP}endencies'

# %% ../nbs/57_pkgs.ipynb 11
SUBCATS = f'{SUB}{CATS}'
SUBCATEGORIES = f'{SUB}{CATEGORIES}'

# %% ../nbs/57_pkgs.ipynb 12
CHANNEL = 'channel'
CHANNELS = f'{CHANNEL}s'

# %% ../nbs/57_pkgs.ipynb 13
ONLY = 'only'
PIP_ONLY = f'{PIP}_{ONLY}'
CUDA_ONLY = f'cuda_{ONLY}'

# %% ../nbs/57_pkgs.ipynb 14
PYPI_NAME = f'{PYPI}_{NAME}'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/53_mods.ipynb.

# %% auto 0
__all__ = ['OS', 'SYS', 'TF', 'TORCH', 'TQDM', 'RICH', 'TYPER', 'SCANPY', 'SCPREP', 'ANNDATA', 'PHATE', 'MAGIC', 'NUMPY',
           'PANDAS', 'SCIPY', 'SEABORN', 'MATPLOTLIB', 'IPYTHON', 'BEARTYPE']

# %% ../nbs/53_mods.ipynb 5
OS = 'os'
SYS = 'sys'
TF = 'tf'
TORCH = 'torch'

TQDM = 'tqdm'
RICH = 'rich'
TYPER = 'typer'

SCANPY = 'scanpy'
SCPREP = 'scprep'
ANNDATA = 'anndata'

PHATE = 'phate'
MAGIC = 'magic'

NUMPY = 'numpy'
PANDAS = 'pandas'
SCIPY = 'scipy'

SEABORN = 'seaborn'
MATPLOTLIB = 'matplotlib'

IPYTHON = 'ipython'
BEARTYPE = 'beartype'



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/56_vers.ipynb.

# %% auto 0
__all__ = ['VER', 'PRE', 'POST', 'EPOCH', 'MAJOR', 'MINOR', 'MICRO', 'PUBLIC', 'SERIAL', 'RELEASE', 'VERSION', 'VERSION_INFO',
           'BASE_VERSION', 'RELEASELEVEL']

# %% ../nbs/56_vers.ipynb 4
from .args import TYPE

# %% ../nbs/56_vers.ipynb 5
VER = 'ver'

PRE = 'pre'
POST = 'post'
EPOCH = 'epoch'
MAJOR = 'major'
MINOR = 'minor'
MICRO = 'micro'

PUBLIC = 'public'
SERIAL = 'serial'

RELEASE = 'release'
VERSION = f'{VER}sion'

VERSION_INFO = f'{VERSION}_info'
BASE_VERSION = f'base_{VERSION}'

RELEASELEVEL = f'{RELEASE}level'
